package channelpoints

import (
	"context"
	"net/http"
	"net/url"

	"github.com/google/go-querystring/query"
)

type DeleteCustomRewardParams struct {
	// The ID of the broadcaster that created the custom reward. This ID must match the user ID found in the OAuth token.
	BroadcasterID string `url:"broadcaster_id"`

	// The ID of the custom reward to delete.
	ID string `url:"id"`
}

// Deletes a custom reward that the broadcaster created.
//
// The app used to create the reward is the only app that may delete it.
// If the reward’s redemption status is UNFULFILLED at the time the reward is deleted, its redemption status is marked as FULFILLED.
//
// Requires a user access token that includes the channel:manage:redemptions scope.
func (c *ChannelPoints) DeleteCustomReward(ctx context.Context, params *DeleteCustomRewardParams) error {
	v, _ := query.Values(params)
	endpoint := c.baseUrl.ResolveReference(&url.URL{Path: "channel_points/custom_rewards", RawQuery: v.Encode()})

	req, err := http.NewRequestWithContext(ctx, http.MethodDelete, endpoint.String(), nil)
	if err != nil {
		return err
	}

	res, err := c.client.Do(req)
	if err != nil {
		return err
	}

	defer res.Body.Close()

	return nil
}
