package moderation

import (
	"context"
	"net/http"
	"net/url"

	"github.com/google/go-querystring/query"
)

type UnbanUserParams struct {
	// The ID of the broadcaster whose chat room the user is banned from chatting in.
	BroadcasterID string `url:"broadcaster_id"`

	// The ID of the broadcaster or a user that has permission to moderate the broadcaster’s chat room.
	// This ID must match the user ID in the user access token.
	ModeratorID string `url:"moderator_id"`

	// The ID of the user to remove the ban or timeout from.
	UserID string `url:"user_id"`
}

// Removes the ban or timeout that was placed on the specified user.
//
// # To ban a user, see Ban user
//
// Requires a user access token that includes the moderator:manage:banned_users scope.
func (m *Moderation) UnbanUser(ctx context.Context, params *UnbanUserParams) error {
	v, _ := query.Values(params)
	endpoint := m.baseUrl.ResolveReference(&url.URL{Path: "moderation/bans", RawQuery: v.Encode()})

	req, err := http.NewRequestWithContext(ctx, http.MethodDelete, endpoint.String(), nil)
	if err != nil {
		return err
	}

	res, err := m.client.Do(req)
	if err != nil {
		return err
	}
	defer res.Body.Close()

	return nil
}
