package schedule

import (
	"context"
	"net/http"
	"net/url"

	"github.com/google/go-querystring/query"
)

type DeleteChannelStreamScheduleSegmentParams struct {
	// The ID of the broadcaster that owns the streaming schedule. This ID must match the user ID in the user access token.
	BroadcasterId string `url:"broadcaster_id"`

	// The ID of the broadcast segment to remove.
	Id string `url:"id"`
}

// Removes a broadcast segment from the broadcaster’s streaming schedule.
//
// NOTE: For recurring segments, removing a segment removes all segments in the recurring schedule.
//
// Requires a user access token that includes the channel:manage:schedule scope.
func (s *Schedule) DeleteChannelStreamScheduleSegment(ctx context.Context, params *DeleteChannelStreamScheduleSegmentParams) error {
	v, _ := query.Values(params)
	endpoint := s.baseUrl.ResolveReference(&url.URL{Path: "schedule/segment", RawQuery: v.Encode()})

	req, err := http.NewRequestWithContext(ctx, http.MethodDelete, endpoint.String(), nil)
	if err != nil {
		return err
	}

	res, err := s.client.Do(req)
	if err != nil {
		return err
	}
	defer res.Body.Close()

	return nil
}
